<?php

namespace Litecms\PlanSettting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\PlanSettting\Models\PlanSettings;

class PlanSettingsPolicy
{

    /**
     * Determine if the given user can view the plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, PlanSettings $plan_settings)
    {
        if ($user->canDo('plan_settting.plan_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $plan_settings->user_id == user_id() && $plan_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan_settting.plan_settings.create');
    }

    /**
     * Determine if the given user can update the given plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, PlanSettings $plan_settings)
    {
        if ($user->canDo('plan_settting.plan_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $plan_settings->user_id == user_id() && $plan_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PlanSettings $plan_settings)
    {
        return $plan_settings->user_id == user_id() && $plan_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PlanSettings $plan_settings)
    {
        if ($user->canDo('plan_settting.plan_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plan_settings.
     *
     * @param UserPolicy $user
     * @param PlanSettings $plan_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PlanSettings $plan_settings)
    {
        if ($user->canDo('plan_settting.plan_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
