<?php

namespace Litecms\PlanSettting\Providers;

use Illuminate\Support\ServiceProvider;

class PlanSetttingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'plan_settting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'plan_settting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.plan_settting', function ($app) {
            return $this->app->make('Litecms\PlanSettting\PlanSettting');
        });

                // Bind PlanSettings to repository
        $this->app->bind(
            'Litecms\PlanSettting\Interfaces\PlanSettingsRepositoryInterface',
            \Litecms\PlanSettting\Repositories\Eloquent\PlanSettingsRepository::class
        );

        $this->app->register(\Litecms\PlanSettting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\PlanSettting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.plan_settting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/plan_settting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/plan_settting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/plan_settting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
